import os

###--------------------------------------------------------------------------------------------------###
###--------------------------------------------------------------------------------------------------###

#GHOST Processing Configuration File 
ghost_version = '1.3.2'

#define the data root directory (i.e. where the observations are stored)
data_root = '/gpfs/projects/bsc32/AC_cache/obs/ghost/' 

#define the processing root directory (i.e. where the processing is being run from)
process_root = os.getcwd().split('/run')[0]

#define the QOS (Quality of Service) used to manage jobs on the SLURM system
#it is possible to define the qos of the pipeline/stage levels of submission
#OPTIONS: bsc_es (max walltime of 2 days), prace (max walltime of 3 days), debug (max walltime of 2 hours), class_a (max walltime of 2 hours), class_b (max walltime of 2 hours)
qos_pipeline = 'bsc_es'
qos_stage = 'debug'

#define the chunk size to process GHOST stage tasks (i.e. the size of CPU chunks used to process tasks)
#this should not exceed the number of CPUs per node on machine (160 virtual cores/40 physical cores on power9, 48 physical cores on marenostrum4)
chunk_size = 20

#define job array limit to process GHOST stage tasks (i.e. the number of CPU chunks allowed to be submitted simultaneously)
job_array_limit = 100

#define the maximum number of stations than can be should be processed for network
max_N_stations = 5000

#define if previous stage temporary files should be removed after stage completion
remove_temporary_data_files_after_stage = False 

#define if multithreading should be used when processing tasks (i.e. use all threads per physical CPU)
multithreading = False

#define if there is an error .out file created for submitted process
error_out_file = True

###--------------------------------------------------------------------------------------------------###
###--------------------------------------------------------------------------------------------------###
# NETWORKS (list of networks whose data you wish to process)
# VALID OPTIONS: AERONET_v3, CANADA_NAPS, CAPMoN, CHILE_SINCA, EANET, EBAS, 
#                EEA_AIRBASE, EEA_AQ_eReporting, JAPAN_NIES, MEXICO_CDMX, MITECO, 
#                NCDC_ISD, NYSERDA, SEARCH, UK_AIR, 
#                US_EPA_AQS, US_EPA_CASTNET, US_NADP_AMoN, WMO_WDCGG
networks = ['EBAS']

# PARAMETERS (list of parameters that you wish to process)
# Gases:                                      O3, NO, NO2, SO2, CO, CH4, C2H4, C2H6, C3H6, C3H8, ISOPRENE, C6H6, C7H8, C10H16, NMVOC, VOC, NMHC, HC, 
#                                            NH3, HNO3, PAN, HCHO, HCl, HF, H2S
# Particulate Matter - size differentiated : PM10, PM2.5, PM1
# Particulate Matter - speciated:             Al, As, BC, eBC, C, Ca++, Cd, Cl-, Co, Cr, Cu, DUST, EC, Fe, Hg, K+, Mg++, Mn, MSA, Na+, NH4+, 
#                                            NH4NO3, Ni, NO3-, OC, Pb, Se, SO4--, SO4--_NSS, SO4--_SS, V, Zn
# PM10 - speciated:                           PM10_Al, PM10_As, PM10_BC, PM10_eBC, PM10_C, PM10_Ca++, PM10_Cd, PM10_Cl-, PM10_Co,
#                                            PM10_Cr, PM10_Cu, PM10_DUST, PM10_EC, PM10_Fe, PM10_Hg, PM10_K+, PM10_Mg++, PM10_Mn, PM10_MSA, PM10_Na+,
#                                            PM10_NH4+, PM10_NH4NO3, PM10_Ni, PM10_NO3-, PM10_OC, PM10_Pb, PM10_Se, PM10_SO4--,
#                                            PM10_SO4--_NSS, PM10_SO4--_SS, PM10_V, PM10_Zn
# PM2.5 - speciated:                          PM2.5_Al, PM2.5_As, PM2.5_BC, PM2.5_eBC, PM2.5_C, PM2.5_Ca++, PM2.5_Cd, PM2.5_Cl-,
#                                            PM2.5_Co, PM2.5_Cr, PM2.5_Cu, PM2.5_DUST, PM2.5_EC, PM2.5_Fe, PM2.5_Hg, PM2.5_K+, PM2.5_Mg++, PM2.5_Mn,
#                                            PM2.5_MSA, PM2.5_Na+, PM2.5_NH4+, PM2.5_NH4NO3, PM2.5_Ni, PM2.5_NO3-, PM2.5_OC,
#                                            PM2.5_Pb, PM2.5_Se, PM2.5_SO4--, PM2.5_SO4--_NSS, PM2.5_SO4--_SS, PM2.5_V, PM2.5_Zn
# PM1 - speciated:                            PM1_Al, PM1_As, PM1_BC, PM1_eBC, PM1_C, PM1_Ca++, PM1_Cd, PM1_Cl-, PM1_Co, PM1_Cr,
#                                            PM1_Cu, PM1_DUST, PM1_EC, PM1_Fe, PM1_Hg, PM1_K+, PM1_Mg++, PM1_Mn, PM1_MSA, PM1_Na+, PM1_NH4+, PM1_NH4NO3, 
#                                            PM1_Ni, PM1_NO3-, PM1_OC, PM1_Pb, PM1_Se, PM1_SO4--, PM1_SO4--_NSS, PM1_SO4--_SS, PM1_V, PM1_Zn
# AOD:                                        AOD_500nm, AOD_500nm_COARSE, AOD_500nm_FINE, FINE_MODE_FRAC_500nm, AOD_380nm, AOD_440nm,
#                                            AOD_550nm, AOD_675nm, AOD_870nm, AOD_1020nm, AE_440-870nm
# Precipitation speciated:                    Al_PREC, As_PREC, Ca++_PREC, Cd_PREC, Cl-_PREC, Co_PREC, Cr_PREC, Cu_PREC, Fe_PREC, Hg_PREC,
#                                            K+_PREC, Mg++_PREC, Mn_PREC, MSA_PREC, Na+_PREC, NH4+_PREC, NH4NO3_PREC, Ni_PREC,
#                                            NO3-_PREC, Pb_PREC, Se_PREC, SO4--_PREC, SO4--_NSS_PREC, SO4--_SS_PREC, V_PREC, Zn_PREC
# Wet Deposition speciated:                   Al_WETDEP, As_WETDEP, Ca++_WETDEP, Cd_WETDEP, Cl-_WETDEP, Co_WETDEP, Cr_WETDEP, Cu_WETDEP, Fe_WETDEP, 
#                                            Hg_WETDEP, K+_WETDEP, Mg++_WETDEP, Mn_WETDEP, MSA_WETDEP, Na+_WETDEP, NH4+_WETDEP, NH4NO3_WETDEP, Ni_WETDEP,
#                                            NO3-_WETDEP, Pb_WETDEP, Se_WETDEP, SO4--_WETDEP, SO4--_NSS_WETDEP, SO4--_SS_WETDEP, V_WETDEP, Zn_WETDEP
# Meteorology:                                WND_DIR_10M, WND_SPD_10M, TEMP_2M, RH_2M, SST, DEW_PT_2M, PRES_2M, SLP,
#                                            PREC_ACCUM, SNOW_ACCUM, SNOW_DEPTH, CEILING_HEIGHT, VIS_DIST, CLOUD_CVG, CLOUD_CVG_FRAC

#parameters = ['O3', 'NO', 'NO2', 'SO2', 'CO', 'CH4', 'C2H4', 'C2H6', 'C3H6', 'C3H8', 'ISOPRENE', 'C6H6', 'C7H8', 'C10H16', 'NMVOC', 'VOC', 'NMHC', 'HC', 'NH3', 'HNO3', 'PAN', 'HCHO', 'HCl', 'HF', 'H2S',
#              'PM10', 'PM2.5', 'PM1',
#              'Al', 'As', 'BC', 'eBC', 'C', 'Ca++', 'Cd', 'Cl-', 'Co', 'Cr', 'Cu', 'DUST', 'EC', 'Fe', 'Hg', 'K+', 'Mg++', 'Mn', 'MSA', 'Na+', 'NH4+', 'NH4NO3', 'Ni', 'NO3-', 'OC', 'Pb', 'Se', 'SO4--', 'SO4--_NSS', 'SO4--_SS', 'V', 'Zn',
#              'PM10_Al', 'PM10_As', 'PM10_BC', 'PM10_eBC', 'PM10_C', 'PM10_Ca++', 'PM10_Cd', 'PM10_Cl-', 'PM10_Co', 'PM10_Cr', 'PM10_Cu', 'PM10_DUST', 'PM10_EC', 'PM10_Fe', 'PM10_Hg', 'PM10_K+', 'PM10_Mg++', 'PM10_Mn', 'PM10_MSA', 'PM10_Na+', 'PM10_NH4+', 'PM10_NH4NO3', 'PM10_Ni', 'PM10_NO3-', 'PM10_OC', 'PM10_Pb', 'PM10_Se', 'PM10_SO4--', 'PM10_SO4--_NSS', 'PM10_SO4--_SS', 'PM10_V', 'PM10_Zn',
#              'PM2.5_Al', 'PM2.5_As', 'PM2.5_BC', 'PM2.5_eBC', 'PM2.5_C', 'PM2.5_Ca++', 'PM2.5_Cd', 'PM2.5_Cl-', 'PM2.5_Co', 'PM2.5_Cr', 'PM2.5_Cu', 'PM2.5_DUST', 'PM2.5_EC', 'PM2.5_Fe', 'PM2.5_Hg', 'PM2.5_K+', 'PM2.5_Mg++', 'PM2.5_Mn', 'PM2.5_MSA', 'PM2.5_Na+', 'PM2.5_NH4+', 'PM2.5_NH4NO3', 'PM2.5_Ni', 'PM2.5_NO3-', 'PM2.5_OC', 'PM2.5_Pb', 'PM2.5_Se', 'PM2.5_SO4--', 'PM2.5_SO4--_NSS', 'PM2.5_SO4--_SS', 'PM2.5_V', 'PM2.5_Zn',
#              'PM1_Al', 'PM1_As', 'PM1_BC', 'PM1_eBC', 'PM1_C', 'PM1_Ca++', 'PM1_Cd', 'PM1_Cl-', 'PM1_Co', 'PM1_Cr', 'PM1_Cu', 'PM1_DUST', 'PM1_EC', 'PM1_Fe', 'PM1_Hg', 'PM1_K+', 'PM1_Mg++', 'PM1_Mn', 'PM1_MSA', 'PM1_Na+', 'PM1_NH4+', 'PM1_NH4NO3', 'PM1_Ni', 'PM1_NO3-', 'PM1_OC', 'PM1_Pb', 'PM1_Se', 'PM1_SO4--', 'PM1_SO4--_NSS', 'PM1_SO4--_SS', 'PM1_V', 'PM1_Zn']
#              'AOD_500nm', 'AOD_500nm_COARSE', 'AOD_500nm_FINE', 'FINE_MODE_FRAC_500nm', 'AOD_380nm', 'AOD_440nm', 'AOD_550nm', 'AOD_675nm', 'AOD_870nm', 'AOD_1020nm', 'AE_440-870nm',
#              'Al_PREC', 'As_PREC', 'Ca++_PREC', 'Cd_PREC', 'Cl-_PREC', 'Co_PREC', 'Cr_PREC', 'Cu_PREC', 'Fe_PREC', 'Hg_PREC', 'K+_PREC', 'Mg++_PREC', 'Mn_PREC', 'MSA_PREC', 'Na+_PREC', 'NH4+_PREC', 'NH4NO3_PREC', 'Ni_PREC', 'NO3-_PREC', 'Pb_PREC', 'Se_PREC', 'SO4--_PREC', 'SO4--_NSS_PREC', 'SO4--_SS_PREC', 'V_PREC', 'Zn_PREC',
#              'Al_WETDEP', 'As_WETDEP', 'Ca++_WETDEP', 'Cd_WETDEP', 'Cl-_WETDEP', 'Co_WETDEP', 'Cr_WETDEP', 'Cu_WETDEP', 'Fe_WETDEP', 'Hg_WETDEP', 'K+_WETDEP', 'Mg++_WETDEP', 'Mn_WETDEP', 'MSA_WETDEP', 'Na+_WETDEP', 'NH4+_WETDEP', 'NH4NO3_WETDEP', 'Ni_WETDEP', 'NO3-_WETDEP', 'Pb_WETDEP', 'Se_WETDEP', 'SO4--_WETDEP', 'SO4--_NSS_WETDEP', 'SO4--_SS_WETDEP', 'V_WETDEP', 'Zn_WETDEP',
#              'WND_DIR_10M','WND_SPD_10M','TEMP_2M','RH_2M','SST','DEW_PT_2M','PRES_2M','SLP','PREC_ACCUM','SNOW_ACCUM','SNOW_DEPTH','CEILING_HEIGHT','VIS_DIST','CLOUD_CVG','CLOUD_CVG_FRAC']
parameters = ['HCl']

#START_DATE = YYYYMM (start year of processed data file - should be fixed as '197001')
start_date = '197001'

#END_DATE   = YYYYMM (end year of processed data file - should be first month of current year)
end_date = '202007'

#TEMPORAL_RESOLUTIONS = H, 3H, 6H, D, M, HI, 3HI, 6HI (temporal resolution desired of merged output netCDF files: hourly, 3hourly, 6 hourly, daily, monthly, hourly instantaneous, 3hourly instantaneous, 6hourly instantaneous)       
temporal_resolutions = ['H','3H','6H','D','M']

#REGIONS = GLOBAL, EU, IP, NA (this works by selectively keeping data within a defined rectangle per region)
regions = ['GLOBAL']

#STAGES_TO_PROCESS (list of GHOST stages that you wish to process)

#PARSING OF NETWORK DATA FILES PARSING TO STATION SPECIFIC .npz FILES
#  S1 = Raw network file parse
#  S2 = Concatenate parsed station data files / Split stations by significantly changing locational information
#  S3 = Add globally gridded metadata / Quality control / Add temporal classification codes

#TEMPORAL AVERAGING/AGGREGATION OF STATIONS TO netCDF
#  T1 = Temporally averaging by station
#  T2 = Aggregate temporally averaged station data in monthly netCDFs
#stages_to_process = ['S1','S2','S3','T1','T2']
stages_to_process = ['S1']
###--------------------------------------------------------------------------------------------------###
###--------------------------------------------------------------------------------------------------###